==> larq-zoo-1.0b4.tar.gz: larq-zoo-1.0b4/README.md <==
# Larq Zoo

[![GitHub Actions](https://github.com/larq/zoo/workflows/Unittest/badge.svg)](https://github.com/larq/zoo/actions?workflow=Unittest) [![Codecov](https://img.shields.io/codecov/c/github/larq/zoo)](https://codecov.io/github/larq/zoo?branch=master) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/larq-zoo.svg)](https://pypi.org/project/larq-zoo/) [![PyPI](https://img.shields.io/pypi/v/larq-zoo.svg)](https://pypi.org/project/larq-zoo/) [![Join the community on Spectrum](https://withspectrum.github.io/badge/badge.svg)](https://spectrum.chat/larq) [![PyPI - License](https://img.shields.io/pypi/l/larq-zoo.svg)](https://github.com/plumerai/larq-zoo/blob/master/LICENSE) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

For more information, see [larq.dev/zoo](https://docs.larq.dev/zoo/).

*Larq Zoo is part of a family of libraries for BNN development; you can also check out [Larq](https://github.com/larq/larq) for building and training BNNs and [Larq Compute Engine](https://github.com/larq/compute-engine) for deployment on mobile and edge devices.*

## Requirements

Before installing Larq Zoo, please install:

- [Python](https://python.org) version `3.6` or `3.7`
- [Tensorflow](https://www.tensorflow.org/install) version `1.14+` or `2.0.0`

## Installation

You can install Larq Zoo with Python's [pip](https://pip.pypa.io/en/stable/) package manager:

```shell
pip install larq-zoo
```

## About

Larq Zoo is being developed by a team of deep learning researchers and engineers at Plumerai to help accelerate both our own research and the general adoption of Binarized Neural Networks.

==> larq-zoo-1.0.5.tar.gz: larq-zoo-1.0.5/README.md <==
# Larq Zoo

[![GitHub Actions](https://github.com/larq/zoo/workflows/Unittest/badge.svg)](https://github.com/larq/zoo/actions?workflow=Unittest) [![Codecov](https://img.shields.io/codecov/c/github/larq/zoo)](https://codecov.io/github/larq/zoo?branch=master) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/larq-zoo.svg)](https://pypi.org/project/larq-zoo/) [![PyPI](https://img.shields.io/pypi/v/larq-zoo.svg)](https://pypi.org/project/larq-zoo/) [![Join the community on Spectrum](https://withspectrum.github.io/badge/badge.svg)](https://spectrum.chat/larq) [![PyPI - License](https://img.shields.io/pypi/l/larq-zoo.svg)](https://github.com/plumerai/larq-zoo/blob/master/LICENSE) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

For more information, see [larq.dev/zoo](https://docs.larq.dev/zoo/).

*Larq Zoo is part of a family of libraries for BNN development; you can also check out [Larq](https://github.com/larq/larq) for building and training BNNs and [Larq Compute Engine](https://github.com/larq/compute-engine) for deployment on mobile and edge devices.*

## Requirements

Before installing Larq Zoo, please install:

- [Python](https://python.org) version `3.6` or `3.7`
- [Tensorflow](https://www.tensorflow.org/install) version `1.15` or `2.0+`

## Installation

You can install Larq Zoo with Python's [pip](https://pip.pypa.io/en/stable/) package manager:

```shell
pip install larq-zoo
```

## About

Larq Zoo is being developed by a team of deep learning researchers and engineers at Plumerai to help accelerate both our own research and the general adoption of Binarized Neural Networks.
